package cn.com.brilliance.doc.controller;

import cn.com.brilliance.doc.config.DocBean;
import cn.com.brilliance.doc.service.PreviewService;
import cn.com.brilliance.doc.service.WordTemplateService;
import cn.com.brilliance.doc.utils.WordToPDF;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpRequest;
import org.springframework.web.bind.annotation.*;
import javax.servlet.http.HttpServletResponse;


import java.io.IOException;
import java.util.Map;


/**
 * @auhotr weiguanying
 * @date 20230220
 * @description 文件处理
 */
@RestController
@RequestMapping("/api")
@Slf4j
public class FileController {

    @Autowired
    private PreviewService previewService;

    @Autowired
    private WordTemplateService wordTemplateService;

    @Autowired
    private DocBean docBean;


    /**
     * @auhotr weiguanying
     * @date 20230220
     * @description 返回文件base64字符串对象给前端做预览
     */
    @PostMapping("/filePreview")
    public String filePreview(@RequestParam("fileName") String fileName) throws IOException {
        return previewService.preview(fileName);
    }

    /**
     * @param templateName 模板名称
     * @return base64字符串
     * @throws IOException
     * @auhotr weiguanying
     * @date 20230220
     * @description 通过docx模板文件生成docx并返回前端预览
     */
    @PostMapping("/templatePreview")
    public String templatePreview(@RequestParam("templateName") String templateName) throws IOException {
        String fileName = wordTemplateService.docxTemplateToDocx(templateName);
        return previewService.preview(fileName);
    }

    @PostMapping("/wordToPdf")
    public String wordToPdf(@RequestParam("filePath") String filePath, @RequestParam("targetPath") String targetPath) {
        filePath = docBean.getFilePath() + filePath;
        targetPath = docBean.getFilePath() + targetPath;
        String licenseKey = docBean.getSpireKey();
        WordToPDF wordToPDF = new WordToPDF();
        wordToPDF.doxcTopdf(filePath, targetPath, licenseKey);
        return targetPath;
    }
    /**
     * word-docx模板生成word-docx
     * @param paramMap map
     * @return
     * {"fileName":"222.docx","templateName":"222.docx","templateData":{"title":"1111","date":"2222","brNo":"3333","amount":"4444","no":"4444","bankName":"BankName"},"text":"text111","year":"2023","month":"02","day":"27","num1":"num111","num2":"num222","lines":"Java平台由Java虚拟机"}
     */
    @PostMapping("templateWord")
    public String wordTemplateToWord(@RequestBody Map<String, Object> paramMap) {
        return wordTemplateService.poiCreateWord(paramMap);
    }

    /**
     *
     * 读取模板文件并生成docx返回base码预览
     * @param paramMap 模板所需参数
     * @param response 请求应答
     * @return
     * @throws IOException
     */
    @PostMapping("word")
    public String wordConvertAndPreview(@RequestBody Map<String, Object> paramMap, HttpServletResponse response) throws IOException {
       return  wordTemplateService.wordConvertAndPreview(paramMap,response);
    }
}
